-- Main frame
local BankChecker = CreateFrame('Frame','BankCheckerMain')

-- Variables
BankChecker.bankBags = {}
BankChecker.isBangCheckerOpener = false
BankChecker.selectedCharacter = nil
BankChecker.closeCount = 0

-- Events
BankChecker:RegisterEvent('ADDON_LOADED')
BankChecker:RegisterEvent('BANKFRAME_OPENED')
BankChecker:RegisterEvent('BANKFRAME_CLOSED')
BankChecker:RegisterEvent('PLAYER_MONEY')
BankChecker:RegisterEvent('GOSSIP_SHOW')
BankChecker:RegisterEvent('ITEM_PUSH')

-- Event functions
BankChecker:SetScript('OnEvent', function(_, event, arg1)
	if event == 'ADDON_LOADED' and arg1 == 'BankChecker' then
		if select(4,GetAddOnInfo('Bagnon')) == true then 
			BankChecker:UnregisterEvent('ADDON_LOADED')
			BankChecker:UnregisterEvent('BANKFRAME_OPENED')
			BankChecker:UnregisterEvent('BANKFRAME_CLOSED')
			BankChecker:UnregisterEvent('PLAYER_MONEY')
			BankChecker:UnregisterEvent('GOSSIP_SHOW')
			BankChecker:UnregisterEvent('ITEM_PUSH')
			BankChecker.print('Sorry. BankChecker is not compatible with Bagnon.')
			SlashCmdList['BANKCHECKER'] = nil
			return
		else
			BankChecker.print('Addon loaded.')								
		end
		
		if BankCheckerDB == nil then 
			BankCheckerDB = {}
			BankCheckerDB['characters'] = {}
			BankCheckerDB['minimap'] = nil
			BankCheckerDB['characters'][UnitName('player')] = {}
		else
			if BankCheckerDB['characters'][UnitName('player')] == nil then 
				BankCheckerDB['characters'][UnitName('player')] = {}
			end
			if BankCheckerDB['minimap'] == nil then 
				BankCheckerDB['minimap'] = nil
			end
		end			
		BankChecker.minimapButton()		
		--BankCheckerDB = nil
	elseif event == 'ADDON_LOADED' and arg1 == 'TitanClassic' then
		local TitanButton = CreateFrame('Button', 'TitanPanelBankCheckerButton', nil,'TitanPanelComboTemplate')
		TitanButton.registry = {
			id = 'BankChecker',
			category = "General",
			icon = "Interface\\Icons\\INV_Misc_Coin_02",
			buttonTextFunction = "TitanBankChecker_GetButtonText",
			iconWidth = 16,
			savedVariables = {
				ShowIcon = 1,
				ShowLabelText = 1
			}
		}
		
		function TitanBankChecker_GetButtonText(id)
			return "BankChecker";
		end
		TitanButton:SetScript('OnClick', function(button,clickButton) 
			BankChecker.open()
		end)
	elseif event == 'BANKFRAME_OPENED' then
		if BankChecker.isBangCheckerOpener then			
			BankFramePurchaseInfo:Show()
		end
		--BankChecker.print('Bankframe opened.')
		if BankChecker.characterSelectTitle ~= nil then
			BankChecker.characterSelectTitle:Hide()
			BankChecker.characterSelect:Hide()
			_G['BankFrameMoneyFrameGoldButton']:EnableMouse(true)
			_G['BankFrameMoneyFrameSilverButton']:EnableMouse(true)
			_G['BankFrameMoneyFrameCopperButton']:EnableMouse(true)
			
			for bagID=NUM_BAG_SLOTS+1,NUM_BAG_SLOTS+NUM_BANKBAGSLOTS,1 do -- enable bank bags
				local button = BankSlotsFrame['Bag'..bagID-NUM_BAG_SLOTS]
				button:Enable()
				button:EnableMouse(true)
			end
		end
	elseif event == 'BANKFRAME_CLOSED' then
		BankChecker.updateBank()	
	elseif event == 'PLAYER_MONEY' then
		BankCheckerDB['characters'][UnitName('player')]['money'] = GetMoney()
	elseif event == 'GOSSIP_SHOW' then
		local _, gossipType = GetGossipOptions()
		if gossipType ~= nil and gossipType == 'banker' then
			BankChecker.closeCount = 1
			CloseBankFrame()
		end
	elseif event == 'ITEM_PUSH' then
		-- hotfix to rerender bankbags on crafting
		if BankChecker.isBangCheckerOpener then
			C_Timer.After( 0.0001, function() 
				for bagID=NUM_BAG_SLOTS+1,NUM_BAG_SLOTS+NUM_BANKBAGSLOTS,1 do		
					if _G['ContainerFrame'..bagID]:IsShown() then
						BankChecker.renderBagItems(bagID)
					end		
				end
			end)		
		end
	end
end)

-- Print function
function BankChecker.print(msg)
	if DEFAULT_CHAT_FRAME then
		DEFAULT_CHAT_FRAME:AddMessage(ORANGE_FONT_COLOR_CODE .. '[BankChecker] ' .. BATTLENET_FONT_COLOR_CODE .. msg)
	end
end

-- Update BankChecker data
function BankChecker.updateBank()	
	if BankChecker.isBangCheckerOpener == true then
		BankChecker.isBangCheckerOpener = false
		return
	end
	local isRealBank = false
	for slot=1,NUM_BANKGENERIC_SLOTS,1 do
		if GetContainerItemInfo(BANK_CONTAINER, slot) ~= nil then
			isRealBank = true
			break
		end
	end
	
	if isRealBank and BankChecker.closeCount < 1 then
		BankChecker.closeCount = BankChecker.closeCount + 1			

		for bagID=NUM_BAG_SLOTS+1,NUM_BAG_SLOTS+NUM_BANKBAGSLOTS,1 do -- bags in bank
			local bagName = GetBagName(bagID)
			if bagName ~= nil then
				-- Save bag datas
				local name, link, quality, iLevel, reqLevel, class, subclass, maxStack, equipSlot, texture = GetItemInfo(bagName)
				BankChecker.bankBags[bagID]	= {}
				BankChecker.bankBags[bagID].name = bagName
				BankChecker.bankBags[bagID].id = bagID
				BankChecker.bankBags[bagID].link = link
				BankChecker.bankBags[bagID].slots = GetContainerNumSlots(bagID)
				BankChecker.bankBags[bagID].texture = texture
				BankChecker.bankBags[bagID].items = {}
				
				for slot=1,BankChecker.bankBags[bagID].slots,1 do -- slots in bag
					BankChecker.saveItem(bagID,slot)
				end
			else
				BankChecker.bankBags[bagID] = nil
			end							
		end
			
		bagID = BANK_CONTAINER 
		BankChecker.bankBags[bagID]	= {}
		BankChecker.bankBags[bagID].items = {}
		for slot=1,NUM_BANKGENERIC_SLOTS,1 do	-- generic bankslots		
			 BankChecker.saveItem(bagID,slot)
		end
		
		BankChecker.print('Bank data has been updated for ' .. UnitName('player')..'.')		
		
		BankCheckerDB['characters'][UnitName('player')] = BankChecker.bankBags
		BankCheckerDB['characters'][UnitName('player')]['money'] = GetMoney()
		BankCheckerDB['characters'][UnitName('player')]['bankSlots'] = GetNumBankSlots()
	else 
		BankChecker.closeCount = 0
	end
end

-- Get item's data and save it to BankChecker
function BankChecker.saveItem(bagID,slot)	
	local texture, itemCount, locked, quality, readable, lootable, itemLink = GetContainerItemInfo(bagID, slot)				
	if texture ~= nil then
		BankChecker.bankBags[bagID].items[slot] = {}
		BankChecker.bankBags[bagID].items[slot].count = itemCount
		BankChecker.bankBags[bagID].items[slot].link = itemLink
		BankChecker.bankBags[bagID].items[slot].position = slot
		BankChecker.bankBags[bagID].items[slot].texture = texture
		_,_,itemID = string.find(itemLink, 'item:(%d+)')
		local start, duration, enable = GetItemCooldown(itemID)
		BankChecker.bankBags[bagID].items[slot].cooldown = {}
		BankChecker.bankBags[bagID].items[slot].cooldown.start = start
		BankChecker.bankBags[bagID].items[slot].cooldown.duration = duration
		BankChecker.bankBags[bagID].items[slot].cooldown.enable = enable
	end
end

function BankChecker.openBank(character)	
	local _, gossipType = GetGossipOptions()
	if gossipType ~= nil and gossipType == 'banker' then
		SelectGossipOption(1)
		return
	end
	
	BankFrame_ShowPanel(BANK_PANELS[1].name)
	BankFrameTitleText:SetText(character..'\'s bank')
	
	SetPortraitToTexture(BankPortraitTexture,'Interface\\Icons\\INV_Misc_Coin_02')
	CloseAllBags(BankFrame)
		
	for index = 1,NUM_BANKGENERIC_SLOTS, 1 do
		local item = BankCheckerDB['characters'][character][BANK_CONTAINER].items[index]
		BankChecker.buttonChange(index,item)
	end
	
	for bagID=NUM_BAG_SLOTS+1,NUM_BAG_SLOTS+NUM_BANKBAGSLOTS,1 do
		local item = BankCheckerDB['characters'][character][bagID]
		BankChecker.buttonChange(bagID,BankCheckerDB['characters'][character][bagID],1)
	end
	
	BankFramePurchaseInfo:Hide()
	MoneyFrame_Update('BankFrameMoneyFrame', BankCheckerDB['characters'][BankChecker.selectedCharacter]['money'])
	_G['BankFrameMoneyFrameGoldButton']:EnableMouse(false)
	_G['BankFrameMoneyFrameSilverButton']:EnableMouse(false)
	_G['BankFrameMoneyFrameCopperButton']:EnableMouse(false)
	
	if (BankChecker.characterSelect == nil) then -- Init character select area if not exists
		BankChecker.characterSelectTitle = BankFrame:CreateFontString(nil, 'OVERLAY', 'GameFontNormal')
		BankChecker.characterSelectTitle:SetPoint('TOPLEFT',36,-336)
		BankChecker.characterSelectTitle:SetFont(STANDARD_TEXT_FONT, 12)
		BankChecker.characterSelectTitle:SetTextColor(NORMAL_FONT_COLOR.r,NORMAL_FONT_COLOR.g,NORMAL_FONT_COLOR.b)		
		BankChecker.characterSelectTitle:SetText('Character: ')
		
		BankChecker.characterSelect = CreateFrame('Button', nil, BankFrame,'UIDropDownMenuTemplate')
		BankChecker.characterSelect:SetPoint('TOPLEFT',20,-350)		
		UIDropDownMenu_JustifyText(BankChecker.characterSelect,'LEFT')
		
		local function OpenDropdown()			
			local dropdown = BankChecker.createDropdown()
			ToggleDropDownMenu(1, nil, dropdown,BankFrame)
			dropdown:Hide()
		end
		
		UIDropDownMenu_Initialize(BankChecker.characterSelect, OpenDropdown)
	end
	
	UIDropDownMenu_SetSelectedValue(BankChecker.characterSelect, BankChecker.selectedCharacter) 
	UIDropDownMenu_SetText(BankChecker.characterSelect,BankChecker.selectedCharacter)
	
	BankChecker.characterSelectTitle:Show()
	BankChecker.characterSelect:Show()
		
	BankChecker.isBangCheckerOpener = true
end

-- Dropdown menu for character select
function BankChecker.createDropdown()
    local dropdown = CreateFrame('Frame', 'BankCheckerDropdown', BankFrame, 'UIDropDownMenuTemplate')

    UIDropDownMenu_Initialize(dropdown, function()				
		table.foreach(BankCheckerDB['characters'], function(k,v) 
			if BankCheckerDB['characters'][k]['bankSlots'] ~= nil then
				local info = {}
				info.text    = k
				info.value   = k	
				info.checked = k == UIDropDownMenu_GetSelectedValue(BankChecker.characterSelect)
				info.func       = function() 	
					BankChecker.selectedCharacter = k
					UIDropDownMenu_SetText(BankChecker.characterSelect,BankChecker.selectedCharacter)
					UIDropDownMenu_SetSelectedValue(BankChecker.characterSelect, BankChecker.selectedCharacter) 
					BankChecker.openBank(BankChecker.selectedCharacter)				
					CloseBankBagFrames()
				end
				UIDropDownMenu_AddButton(info)
			end
		end)				
    end)	

    return dropdown
end


-- Show cooldowns on items
function BankChecker.UpdateCooldown(button,item)
	local start, duration, enable
	
	if item == nil then
		CooldownFrame_Set(_G[button:GetName()..'Cooldown'],0)
	else
		CooldownFrame_Set(_G[button:GetName()..'Cooldown'], item.cooldown.start, item.cooldown.duration, item.cooldown.enable)
		if ( item.cooldown.duration > 0 and item.cooldown.enable == 0 ) then
			SetItemButtonTextureVertexColor(button, 0.4, 0.4, 0.4)
		end
	end
end

-- Show cooldown remainings in tooltips
function BankChecker.tooltipCooldown(button)
	local now = GetTime()*1000
	local startTime,duration = _G[button:GetName()..'Cooldown']:GetCooldownTimes()
	local left = max(startTime+duration-now,0)/1000
	
	local days = floor(left/86400)
	local hours = floor(mod(left, 86400)/3600)
	local minutes = floor(mod(left,3600)/60)
	local seconds = floor(mod(left,60))

	if days > 0 then
		GameTooltip:AddLine('Cooldown remaining: '..format('%2d Days %2d Hrs',days,hours) , 1, 1, 1,true)
	else
		if hours > 0 then
			GameTooltip:AddLine('Cooldown remaining: '..format('%2d Hrs %2d Mins',hours,minutes) , 1, 1, 1,true)
		else
			if minutes > 0 then
				GameTooltip:AddLine('Cooldown remaining: '..format('%02d Mins %02d Secs',minutes,seconds) , 1, 1, 1,true)
			else
				if seconds > 0 then
					GameTooltip:AddLine('Cooldown remaining: '..format('%02d Secs',seconds) , 1, 1, 1,true)
				end
			end
		end
	end
end

-- Change bankframe's buttons to our own
function BankChecker.buttonChange(index,item,isBag) 	
	local button	
	if isBag == 1 then 
		button = BankSlotsFrame['Bag'..index-NUM_BAG_SLOTS]
	else 
		button = BankSlotsFrame['Item'..index]
	end
	local buttonID = button:GetID()	
	local texture = button.icon
	
	if item ~= nil then	-- if item exists	
		texture:SetTexture(item.texture)
		texture:Show()		
		
		if( isBag ) then
			SetItemButtonTextureVertexColor(button, 1.0,1.0,1.0)
			button:Enable()
			button:EnableMouse(true)
			SetItemButtonCount(button,0)
		else
			BankChecker.UpdateCooldown(button,item)
			SetItemButtonCount(button,item.count)
			button:Enable()
		end
		
		button:SetScript('OnEnter', function(self) 
			if BankChecker.isBangCheckerOpener and item ~= nil then
				GameTooltip:SetOwner(self, 'ANCHOR_RIGHT')
				GameTooltip:SetHyperlink(item.link)
				local cooldown = 0
				if not isBag then
					cooldown = _G[self:GetName()..'Cooldown']:GetCooldownDuration()
					if cooldown > 0 then
						BankChecker.tooltipCooldown(self)															
					end	
				end
				
				GameTooltip:Show()
				self.UpdateTooltip = function (self)
					if BankChecker.isBangCheckerOpener and item ~= nil then
						GameTooltip:SetOwner(self, 'ANCHOR_RIGHT')
						GameTooltip:SetHyperlink(item.link)
								
						if cooldown > 0 then
							BankChecker.tooltipCooldown(self)																
						end	
							
						GameTooltip:Show()
						CursorUpdate(self)
					end
				end
			else
				BankFrameItemButton_OnEnter(self)
				self.UpdateTooltip = BankFrameItemButton_OnEnter
				return
			end
		end)
				
	else -- if item not exists
		if( isBag ) then						
			if index-NUM_BAG_SLOTS > BankCheckerDB['characters'][BankChecker.selectedCharacter]['bankSlots'] then
				SetItemButtonTextureVertexColor(button, 1.0,0.1,0.1);
			else
				SetItemButtonTextureVertexColor(button, 1.0,1.0,1.0);
			end
			texture:SetTexture('Interface\\PaperDoll\\UI-PaperDoll-Slot-Bag')
			button:Disable()
			button:EnableMouse(false)
		else			
			texture:Hide()	
			BankChecker.UpdateCooldown(button,nil)
		end
		SetItemButtonCount(button,0)
		
		button:SetScript('OnEnter', function(self) 
			if BankChecker.isBangCheckerOpener then
				GameTooltip:Hide()
			else
				BankFrameItemButton_OnEnter(button)
				button.UpdateTooltip = BankFrameItemButton_OnEnter
				return
			end
		end)
	end	
		
	button:SetScript('OnClick', function(button,clickButton) 
		if BankChecker.isBangCheckerOpener then
			if( isBag ) then
				BankFrameItemButtonBag_OnClick(button)
			else
				if IsShiftKeyDown() then
					local itemLink = BankCheckerDB['characters'][BankChecker.selectedCharacter][BANK_CONTAINER]['items'][buttonID].link
					if AuctionFrame and AuctionFrame:IsVisible() then					
						local itemName = GetItemInfo(itemLink)
						BrowseName:SetText(itemName)
					elseif ACTIVE_CHAT_EDIT_BOX and ACTIVE_CHAT_EDIT_BOX:IsShown() then
						ACTIVE_CHAT_EDIT_BOX:Insert(itemLink)
					end
				end
			end
		else -- default Blizzard BankItemButton functions
			if( isBag ) then
				if ( IsModifiedClick('PICKUPITEM') ) then
					BankFrameItemButtonBag_Pickup(button)
				else
					BankFrameItemButtonBag_OnClick(button, clickButton)
				end				
			else
				if ( IsModifiedClick() ) then
					BankFrameItemButtonGeneric_OnModifiedClick(button, clickButton)
				else
					BankFrameItemButtonGeneric_OnClick(button, clickButton)
				end
			end
		end
	end)
	
end

-- Override Blizzard ToggleBag function
local ToggleBagOld = ToggleBag
function ToggleBag(bagID)
	if BankChecker.isBangCheckerOpener then		
		if (bagID <= NUM_BAG_SLOTS) then
			ToggleBagOld(bagID)
			return
		else
			if BankCheckerDB['characters'][BankChecker.selectedCharacter][bagID] == nil then -- bag button drag hotfix
				return
			end		
		end
		
		if ( IsOptionFrameOpen() ) then
			return
		end

		local containerShowing
		for i=1, NUM_CONTAINER_FRAMES, 1 do
			local frame = _G['ContainerFrame'..i]
			if ( frame:IsShown() and frame:GetID() == bagID ) then
				containerShowing = i
				frame:Hide()
			end
		end
		if ( not containerShowing ) then
			local frame = _G['ContainerFrame'..bagID]	
	
			ContainerFrame_GenerateFrame(frame, BankCheckerDB['characters'][BankChecker.selectedCharacter][bagID].slots, bagID)
			_G[frame:GetName()..'Name']:SetText(BankCheckerDB['characters'][BankChecker.selectedCharacter][bagID].name)
			_G[frame:GetName()..'Portrait']:SetTexture(BankCheckerDB['characters'][BankChecker.selectedCharacter][bagID].texture)					
			BankChecker.renderBagItems(bagID)
		end
	else
		ToggleBagOld(bagID)
	end
end

-- Render container items
function BankChecker.renderBagItems(bagID)
	for i=1,BankCheckerDB['characters'][BankChecker.selectedCharacter][bagID].slots,1 do					
		local index = BankCheckerDB['characters'][BankChecker.selectedCharacter][bagID].slots - i + 1
		local item = BankCheckerDB['characters'][BankChecker.selectedCharacter][bagID]['items'][i]
		local itemButton = _G['ContainerFrame'.. bagID ..'Item'..index]
		local texture = itemButton.icon
		
		if item ~= nil then
			BankChecker.UpdateCooldown(itemButton,item)
			texture:SetTexture(item.texture)
			texture:Show()
			
			SetItemButtonCount(itemButton,item.count)

			itemButton:SetScript('OnEnter', function(self) 
				if BankChecker.isBangCheckerOpener and item ~= nil then
					GameTooltip:SetOwner(self, 'ANCHOR_LEFT')
					GameTooltip:SetHyperlink(item.link)
					local cooldown = _G[self:GetName()..'Cooldown']:GetCooldownDuration()
					if cooldown > 0 then
						BankChecker.tooltipCooldown(self)															
					end	
					
					GameTooltip:Show()
					self.UpdateTooltip = function (self)
						if BankChecker.isBangCheckerOpener and item ~= nil then
							GameTooltip:SetOwner(self, 'ANCHOR_LEFT')
							GameTooltip:SetHyperlink(item.link)
									
							if cooldown > 0 then
								BankChecker.tooltipCooldown(self)																
							end	
								
							GameTooltip:Show()
							CursorUpdate(self)
						end
					end
				else
					ContainerFrameItemButton_OnEnter(self)
					self.UpdateTooltip = ContainerFrameItemButton_OnEnter
					return
				end
			end)
			
			itemButton:SetScript('OnClick', function(itemButton,clickButton) 
				if BankChecker.isBangCheckerOpener then
					if IsShiftKeyDown() then
						local itemLink = BankCheckerDB['characters'][BankChecker.selectedCharacter][itemButton:GetParent():GetID()]['items'][itemButton:GetID()].link
						if AuctionFrame and AuctionFrame:IsVisible() then					
							local itemName = GetItemInfo(itemLink)
							BrowseName:SetText(itemName)
						elseif ACTIVE_CHAT_EDIT_BOX and ACTIVE_CHAT_EDIT_BOX:IsShown() then
							ACTIVE_CHAT_EDIT_BOX:Insert(itemLink)
						end
					end
				else -- default Blizzard ContainerItemButton functions
					local modifiedClick = IsModifiedClick()
					if ( clickButton ~= 'LeftButton' and modifiedClick and IsModifiedClick('AUTOLOOTTOGGLE') ) then
						local _, _, _, _, _, lootable = GetContainerItemInfo(itemButton:GetParent():GetID(), itemButton:GetID())
						if ( lootable ) then
							modifiedClick = false
						end
					end
					if ( modifiedClick ) then
						ContainerFrameItemButton_OnModifiedClick(itemButton, clickButton)
					else
						ContainerFrameItemButton_OnClick(itemButton, clickButton)
					end
				end
			end)
		else			
			itemButton:SetScript('OnEnter', function(self) 
				if BankChecker.isBangCheckerOpener then
					GameTooltip:Hide()
				else
					ContainerFrameItemButton_OnEnter(itemButton)
					itemButton.UpdateTooltip = ContainerFrameItemButton_OnEnter
					return
				end
			end)
		end
		-- remove extendslot blue layer and enable mouse
		itemButton:GetNormalTexture():SetVertexColor(1, 1, 1)
		itemButton.ExtendedOverlay:Hide()
		itemButton.ExtendedOverlay2:Hide()
		itemButton.ExtendedSlot:Hide()
		itemButton.BagStaticBottom:Hide()
		itemButton.BagStaticTop:Hide()
		itemButton:EnableMouse(true)
		itemButton:SetScript('OnUpdate', nil)
		itemButton.isExtended = false						
	end
end


function BankChecker.minimapButton()
	BankChecker.minibtn = CreateFrame("Button", nil, Minimap)
	if (BankCheckerDB['minimap'] == nil) then
		BankCheckerDB['minimap'] = -90
	end
 
	BankChecker.minibtn:SetFrameLevel(8)
	BankChecker.minibtn:SetWidth(32)
	BankChecker.minibtn:SetHeight(32)
	BankChecker.minibtn:SetHighlightTexture('Interface\\Minimap\\UI-Minimap-ZoomButton-Highlight')
	BankChecker.minibtn:SetMovable(true)
	BankChecker.minibtn:SetPoint("TOPLEFT", Minimap, "TOPLEFT", 52 - (80 * cos(BankCheckerDB['minimap'])),(80 * sin(BankCheckerDB['minimap'])) - 52)
	  
	BankChecker.minibtn.overlay = BankChecker.minibtn:CreateTexture(nil, 'OVERLAY')
	BankChecker.minibtn.overlay:SetWidth(53)
	BankChecker.minibtn.overlay:SetHeight(53)
	BankChecker.minibtn.overlay:SetTexture('Interface\\Minimap\\MiniMap-TrackingBorder')
	BankChecker.minibtn.overlay:SetPoint('TOPLEFT', 0,0)

	BankChecker.minibtn.icon = BankChecker.minibtn:CreateTexture(nil, 'BACKGROUND')
	BankChecker.minibtn.icon:SetWidth(20)
	BankChecker.minibtn.icon:SetHeight(20)
	BankChecker.minibtn.icon:SetTexture('Interface\\Icons\\INV_Misc_Coin_02')
	BankChecker.minibtn.icon:SetTexCoord(0.05, 0.95, 0.05, 0.95)
	BankChecker.minibtn.icon:SetPoint('CENTER', 0,0)
	
	local function UpdateMapBtn()
		local Xpoa, Ypoa = GetCursorPosition()
		local Xmin, Ymin = Minimap:GetLeft(), Minimap:GetBottom()
		Xpoa = Xmin - Xpoa / Minimap:GetEffectiveScale() + 70
		Ypoa = Ypoa / Minimap:GetEffectiveScale() - Ymin - 70
		BankCheckerDB['minimap'] = math.deg(math.atan2(Ypoa, Xpoa))
		BankChecker.minibtn:ClearAllPoints()
		BankChecker.minibtn:SetPoint("TOPLEFT", Minimap, "TOPLEFT", 52 - (80 * cos(BankCheckerDB['minimap'])), (80 * sin(BankCheckerDB['minimap'])) - 52)
	end
	 
	BankChecker.minibtn:RegisterForDrag("LeftButton")
	BankChecker.minibtn:SetScript("OnDragStart", function()
		BankChecker.minibtn:StartMoving()
		BankChecker.minibtn:SetScript("OnUpdate", UpdateMapBtn)
	end)
	 
	BankChecker.minibtn:SetScript("OnDragStop", function()
		BankChecker.minibtn:StopMovingOrSizing();
		BankChecker.minibtn:SetScript("OnUpdate", nil)
		UpdateMapBtn();
	end)
	 
	BankChecker.minibtn:SetScript("OnClick",BankChecker.open)

	BankChecker.minibtn:SetScript("OnEnter", function()
		GameTooltip:SetOwner(BankChecker.minibtn, "ANCHOR_BOTTOMLEFT")
		GameTooltip:SetText("BankChecker\n")
		GameTooltip:Show()
	end)
	BankChecker.minibtn:SetScript("OnLeave", function()
		GameTooltip:Hide()
	end)
end

function BankChecker.open()
	if UnitAffectingCombat('player') then
		BankChecker.print('You cannot open BankChecker while you are in combat.')
		return
	end
	if not BankFrame:IsShown() then
		if BankCheckerDB['characters'][UnitName('player')]['bankSlots'] ~= nil then		
			BankChecker.selectedCharacter = UnitName('player')
			BankChecker.openBank(BankChecker.selectedCharacter)		
		else
			local count = 0;
			local lastCharacterName = ""
			table.foreach(BankCheckerDB['characters'], function(k,v) 	
				if v['bankSlots'] ~= nil then
					count = count + 1;
					lastCharacterName = k
				end
			end)
			
			if count > 0 then
				BankChecker.selectedCharacter = lastCharacterName
				BankChecker.openBank(BankChecker.selectedCharacter)	
				BankChecker.print('Your character is not on the list yet. You need to visit a bank first.')
			else
				BankChecker.print('No data yet. First you need to visit your bank with one of your characters.')
			end					
		end
	end
end

-- Slash command
SLASH_BANKCHECKER1 = '/bankchecker'
SlashCmdList['BANKCHECKER'] = function(msg)
	local func,argument  = strsplit(' ',msg,2)
	BankChecker.open()
end 